@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2023 Till Krüss
+ * (c) 2021-2024 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -13,7 +13,7 @@
 /**
  * PHPUnit constraint matching arrays with same elements even in different order.
  */
-class ArrayHasSameValuesConstraint extends \PHPUnit\Framework\Constraint\Constraint
+class ArrayHasSameValuesConstraint extends PHPUnit\Framework\Constraint\Constraint
 {
     protected $array;
 
