@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2023 Till Krüss
+ * (c) 2021-2024 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -237,4 +237,15 @@ BUFFER;
 
         $redis->client('KILL', '127.0.0.1:65535');
     }
+
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 7.3.0
+     */
+    public function testKillWithMaxAgeOption(): void
+    {
+        $redis = $this->getClient();
+
+        $this->assertSame(0, $redis->client('KILL', 'MAXAGE', 100));
+    }
 }
