@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2023 Till Krüss
+ * (c) 2021-2024 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -82,6 +82,16 @@ class SET_Test extends PredisCommandTestCase
         $this->assertSame('bar', $redis->get('foo'));
     }
 
+    /**
+     * @group connected
+     * @group cluster
+     * @requiresRedisVersion >= 6.0.0
+     */
+    public function testSetStringValueUsingCluster(): void
+    {
+        $this->testSetStringValue();
+    }
+
     /**
      * @group connected
      * @requiresRedisVersion >= 2.6.12
@@ -94,6 +104,16 @@ class SET_Test extends PredisCommandTestCase
         $this->assertSame(1, $redis->ttl('foo'));
     }
 
+    /**
+     * @group connected
+     * @group cluster
+     * @requiresRedisVersion >= 6.0.0
+     */
+    public function testSetStringValueWithModifierEXUsingCluster(): void
+    {
+        $this->testSetStringValueWithModifierEX();
+    }
+
     /**
      * @group connected
      * @requiresRedisVersion >= 2.6.12
@@ -109,6 +129,16 @@ class SET_Test extends PredisCommandTestCase
         $this->assertLessThanOrEqual(1000, $pttl);
     }
 
+    /**
+     * @group connected
+     * @group cluster
+     * @requiresRedisVersion >= 6.0.0
+     */
+    public function testSetStringValueWithModifierPXUsingCluster(): void
+    {
+        $this->testSetStringValueWithModifierPX();
+    }
+
     /**
      * @group connected
      * @requiresRedisVersion >= 2.6.12
@@ -121,6 +151,16 @@ class SET_Test extends PredisCommandTestCase
         $this->assertNull($redis->set('foo', 'bar', 'NX'));
     }
 
+    /**
+     * @group connected
+     * @group cluster
+     * @requiresRedisVersion >= 6.0.0
+     */
+    public function testSetStringValueWithModifierNXUsingCluster(): void
+    {
+        $this->testSetStringValueWithModifierNX();
+    }
+
     /**
      * @group connected
      * @requiresRedisVersion >= 2.6.12
@@ -135,11 +175,59 @@ class SET_Test extends PredisCommandTestCase
         $this->assertNull($redis->set('foofoo', 'barbar', 'XX'));
     }
 
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 2.6.12
+     */
+    public function testSetStringDoesNotFailWithExplicitlySetNullArguments(): void
+    {
+        $redis = $this->getClient();
+
+        $this->assertEquals(
+            'OK', $redis->set('foo', 'barbar', null, null, null)
+        );
+    }
+
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 2.6.12
+     */
+    public function testSetNull(): void
+    {
+        $redis = $this->getClient();
+
+        $this->assertEquals(
+            'OK', $redis->set('foo', null)
+        );
+    }
+
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 2.6.12
+     */
+    public function testSetFalse(): void
+    {
+        $redis = $this->getClient();
+
+        $this->assertEquals(
+            'OK', $redis->set('foo', false)
+        );
+    }
+
+    /**
+     * @group connected
+     * @group cluster
+     * @requiresRedisVersion >= 6.0.0
+     */
+    public function testSetStringValueWithModifierXXUsingCluster(): void
+    {
+        $this->testSetStringValueWithModifierXX();
+    }
+
     /**
      * @group connected
      * @group cluster
      * @requiresRedisVersion >= 3.0.0
-     * @return void
      */
     public function testSetStringValueInClusterMode(): void
     {
