@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2023 Till Krüss
+ * (c) 2021-2024 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -117,13 +117,13 @@ class CommunicationExceptionTest extends PredisTestCase
      * @param int                                $code       Exception code.
      * @param Exception                          $inner      Inner exception.
      *
-     * @return \Predis\CommunicationException
+     * @return CommunicationException
      */
     protected function createMockException(
         Connection\NodeConnectionInterface $connection,
         string $message,
         int $code = 0,
-        Exception $inner = null
+        ?Exception $inner = null
     ) {
         return $this->getMockBuilder('Predis\CommunicationException')
             ->setConstructorArgs([$connection, $message, $code, $inner])
