@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2023 Till Krüss
+ * (c) 2021-2024 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -390,7 +390,7 @@ class ReplicationStrategyTest extends PredisTestCase
      *
      * @return array
      */
-    protected function getExpectedCommands(string $type = null): array
+    protected function getExpectedCommands(?string $type = null): array
     {
         $commands = [
             /* commands operating on the connection */
